.. only:: not latex

    ================================
    Front page of the thesis
    ================================


.. toctree::

    glossary
    acknowledgements
    abstract
    introduction
    discord
    daf/index
    conclusion
    thesis_lit
    appendix

